@@ -1,4 +1,6 @@
-#include <platform.h>
+#include <sys/types.h>
+#include <sys/select.h>
+#include <sys/socket.h>
 #include <microhttpd.h>
 #include <time.h>
 
@@ -12,7 +14,7 @@
 char *string_to_base64 (const char *message);
 
 
-int
+static int
 ask_for_authentication (struct MHD_Connection *connection, const char *realm)
 {
   int ret;
@@ -46,7 +48,7 @@ ask_for_authentication (struct MHD_Connection *connection, const char *realm)
   return ret;
 }
 
-int
+static int
 is_authenticated (struct MHD_Connection *connection,
                   const char *username, const char *password)
 {
@@ -72,20 +74,19 @@ is_authenticated (struct MHD_Connection *connection,
   strcat (expected, password);
 
   expected_b64 = string_to_base64 (expected);
+  free (expected);
   if (NULL == expected_b64)
-    return 0;
+       return 0;
 
-  strcpy (expected, strbase);
   authenticated =
     (strcmp (headervalue + strlen (strbase), expected_b64) == 0);
 
   free (expected_b64);
-
   return authenticated;
 }
 
 
-int
+static int
 secret_page (struct MHD_Connection *connection)
 {
   int ret;
@@ -105,7 +106,7 @@ secret_page (struct MHD_Connection *connection)
 }
 
 
-int
+static int
 answer_to_connection (void *cls, struct MHD_Connection *connection,
                       const char *url, const char *method,
                       const char *version, const char *upload_data,
