@@ -439,6 +439,19 @@ MHD_init_daemon_certificate (struct MHD_Daemon *daemon)
   gnutls_datum_t key;
   gnutls_datum_t cert;
 
+  if (daemon->https_mem_trust) {
+		cert.data = (unsigned char *) daemon->https_mem_trust;
+		cert.size = strlen(daemon->https_mem_trust);
+		if (gnutls_certificate_set_x509_trust_mem(daemon->x509_cred, &cert,
+				GNUTLS_X509_FMT_PEM) < 0) {
+#if HAVE_MESSAGES
+			MHD_DLOG(daemon,
+					"Bad trust certificate format\n");
+#endif
+			return -1;
+		}
+	}
+
   /* certificate & key loaded from memory */
   if (daemon->https_mem_cert && daemon->https_mem_key)
     {
@@ -701,7 +714,7 @@ send_param_adapter (struct MHD_Connection *connection,
        (-1 != (fd = connection->response->fd)) )
     {
       /* can use sendfile */
-      offset = (off_t) connection->response_write_position;
+      offset = (off_t) connection->response_write_position + connection->response->fd_off;
       ret = sendfile (connection->socket_fd, 
 		      fd,
 		      &offset,
@@ -752,6 +765,56 @@ socket_set_nonblocking (int fd)
 #endif
 
 
+/**
+ * Create a thread and set the attributes according to our options.
+ * 
+ * @param thread handle to initialize
+ * @param daemon daemon with options
+ * @param start_routine main function of thread
+ * @param arg argument for start_routine
+ * @return 0 on success
+ */
+static int
+create_thread (pthread_t * thread,
+	       const struct MHD_Daemon *daemon,
+	       void *(*start_routine)(void*),
+	       void *arg)
+{
+  pthread_attr_t attr;
+  pthread_attr_t *pattr;
+  int ret;
+  
+  if (daemon->thread_stack_size != 0) 
+    {
+      if (0 != (ret = pthread_attr_init (&attr))) 
+	goto ERR;
+      if (0 != (ret = pthread_attr_setstacksize (&attr, daemon->thread_stack_size)))
+	{
+	  pthread_attr_destroy (&attr);
+	  goto ERR;
+	}
+      pattr = &attr;
+    }
+  else
+    {
+      pattr = NULL;
+    }
+  ret = pthread_create (thread, pattr,
+			start_routine, arg);
+  if (daemon->thread_stack_size != 0) 
+    pthread_attr_destroy (&attr);
+  return ret;
+ ERR:
+#if HAVE_MESSAGES
+  MHD_DLOG (daemon,
+	    "Failed to set thread stack size\n");
+#endif
+  errno = EINVAL;
+  return ret;
+}
+
+
+
 /**
  * Accept an incoming connection and create the MHD_Connection object for
  * it.  This function also enforces policy by way of checking with the
@@ -937,14 +1000,18 @@ MHD_accept_connection (struct MHD_Daemon *daemon)
       gnutls_transport_set_push_function (connection->tls_session,
 					  (gnutls_push_func) &
                                                send_param_adapter);
+
+      if (daemon->https_mem_trust){
+      gnutls_certificate_server_set_request(connection->tls_session, GNUTLS_CERT_REQUEST);
+      }
     }
 #endif
 
   /* attempt to create handler thread */
   if (0 != (daemon->options & MHD_USE_THREAD_PER_CONNECTION))
     {
-      res_thread_create = pthread_create (&connection->pid, NULL,
-                                          &MHD_handle_connection, connection);
+      res_thread_create = create_thread (&connection->pid, daemon,
+					 &MHD_handle_connection, connection);
       if (res_thread_create != 0)
         {
 #if HAVE_MESSAGES
@@ -1042,7 +1109,7 @@ MHD_cleanup_connections (struct MHD_Daemon *daemon)
  *        necessiate the use of a timeout right now).
  */
 int
-MHD_get_timeout (struct MHD_Daemon *daemon, unsigned long long *timeout)
+MHD_get_timeout (struct MHD_Daemon *daemon, unsigned MHD_LONG_LONG *timeout)
 {
   time_t earliest_deadline;
   time_t now;
@@ -1094,7 +1161,7 @@ MHD_select (struct MHD_Daemon *daemon, int may_block)
   fd_set es;
   int max;
   struct timeval timeout;
-  unsigned long long ltimeout;
+  unsigned MHD_LONG_LONG ltimeout;
   int ds;
 
   timeout.tv_sec = 0;
@@ -1422,6 +1489,16 @@ parse_options_va (struct MHD_Daemon *daemon,
 	    FPRINTF (stderr,
 		     "MHD HTTPS option %d passed to MHD but MHD_USE_SSL not set\n",
 		     opt);	  
+#endif
+          break;
+        case MHD_OPTION_HTTPS_MEM_TRUST:
+	  if (0 != (daemon->options & MHD_USE_SSL))
+	    daemon->https_mem_trust = va_arg (ap, const char *);
+#if HAVE_MESSAGES
+	  else
+	    FPRINTF (stderr,
+		     "MHD HTTPS option %d passed to MHD but MHD_USE_SSL not set\n",
+		     opt);
 #endif
           break;
 	case MHD_OPTION_HTTPS_CRED_TYPE:
@@ -1464,6 +1541,9 @@ parse_options_va (struct MHD_Daemon *daemon,
           va_arg (ap, void *);
 #endif
           break;
+        case MHD_OPTION_THREAD_STACK_SIZE:
+          daemon->thread_stack_size = va_arg (ap, size_t);
+          break;
 	case MHD_OPTION_ARRAY:
 	  oa = va_arg (ap, struct MHD_OptionItem*);
 	  i = 0;
@@ -1473,6 +1553,7 @@ parse_options_va (struct MHD_Daemon *daemon,
 		{
 		  /* all options taking 'size_t' */
 		case MHD_OPTION_CONNECTION_MEMORY_LIMIT:
+		case MHD_OPTION_THREAD_STACK_SIZE:
 		  if (MHD_YES != parse_options (daemon,
 						servaddr,
 						opt,
@@ -1507,6 +1588,7 @@ parse_options_va (struct MHD_Daemon *daemon,
 		case MHD_OPTION_SOCK_ADDR:
 		case MHD_OPTION_HTTPS_MEM_KEY:
 		case MHD_OPTION_HTTPS_MEM_CERT:
+		case MHD_OPTION_HTTPS_MEM_TRUST:
 		case MHD_OPTION_HTTPS_PRIORITIES:
 		case MHD_OPTION_ARRAY:
 		  if (MHD_YES != parse_options (daemon,
@@ -1537,7 +1619,8 @@ parse_options_va (struct MHD_Daemon *daemon,
 						(size_t) oa[i].value,
 						oa[i].ptr_value,
 						MHD_OPTION_END))
-		    return MHD_NO;		  
+		    return MHD_NO;
+		  break;
 		default:
 		  return MHD_NO;
 		}
@@ -1551,8 +1634,8 @@ parse_options_va (struct MHD_Daemon *daemon,
           break;
         default:
 #if HAVE_MESSAGES
-          if ((opt >= MHD_OPTION_HTTPS_MEM_KEY) &&
-              (opt <= MHD_OPTION_HTTPS_PRIORITIES))
+          if (((opt >= MHD_OPTION_HTTPS_MEM_KEY) &&
+              (opt <= MHD_OPTION_HTTPS_PRIORITIES)) || (opt == MHD_OPTION_HTTPS_MEM_TRUST))
             {
               FPRINTF (stderr,
                        "MHD HTTPS option %d passed to MHD compiled without HTTPS support\n",
@@ -1710,6 +1793,8 @@ MHD_start_daemon_va (unsigned int options,
       MHD_DLOG (retVal,
 		"MHD poll support only works with MHD_USE_THREAD_PER_CONNECTION\n");
 #endif
+      free (retVal->nnc);
+      pthread_mutex_destroy (&retVal->nnc_lock);
       free (retVal);
       return NULL;
     }
@@ -1895,6 +1980,10 @@ MHD_start_daemon_va (unsigned int options,
 		"Failed to initialize TLS support\n");
 #endif
       CLOSE (socket_fd);
+#ifdef DAUTH_SUPPORT
+      pthread_mutex_destroy (&retVal->nnc_lock);
+      free (retVal->nnc);
+#endif
       pthread_mutex_destroy (&retVal->per_ip_connection_mutex);
       free (retVal);
       return NULL;
@@ -1904,12 +1993,16 @@ MHD_start_daemon_va (unsigned int options,
 	 ( (0 != (options & MHD_USE_SELECT_INTERNALLY)) &&
 	   (0 == retVal->worker_pool_size)) ) && 
        (0 != (res_thread_create =
-	      pthread_create (&retVal->pid, NULL, &MHD_select_thread, retVal))))
+	      create_thread (&retVal->pid, retVal, &MHD_select_thread, retVal))))
     {
 #if HAVE_MESSAGES
       MHD_DLOG (retVal,
                 "Failed to create listen thread: %s\n", 
 		STRERROR (res_thread_create));
+#endif
+#ifdef DAUTH_SUPPORT
+      pthread_mutex_destroy (&retVal->nnc_lock);
+      free (retVal->nnc);
 #endif
       pthread_mutex_destroy (&retVal->per_ip_connection_mutex);
       free (retVal);
@@ -1982,7 +2075,7 @@ MHD_start_daemon_va (unsigned int options,
             ++d->max_connections;
 
           /* Spawn the worker thread */
-          if (0 != (res_thread_create = pthread_create (&d->pid, NULL, &MHD_select_thread, d)))
+          if (0 != (res_thread_create = create_thread (&d->pid, retVal, &MHD_select_thread, d)))
             {
 #if HAVE_MESSAGES
               MHD_DLOG (retVal,
