@@ -27,10 +27,11 @@
 #include "internal.h"
 
 #if HAVE_MESSAGES
+#if DEBUG_STATES
 /**
  * State to string dictionary.
  */
-char *
+const char *
 MHD_state_to_string (enum MHD_CONNECTION_STATE state)
 {
   switch (state)
@@ -82,6 +83,7 @@ MHD_state_to_string (enum MHD_CONNECTION_STATE state)
     }
 }
 #endif
+#endif
 
 #if HAVE_MESSAGES
 /**
