@@ -96,10 +96,12 @@ struct MHD_Pollfd
 
 
 /**
- * Maximum length of a nonce in digest authentication.
- * 32(MD5 Hex) + 8(Timestamp Hex) + 1(NULL)
+ * Maximum length of a nonce in digest authentication.  32(MD5 Hex) +
+ * 8(Timestamp Hex) + 1(NULL); hence 41 should suffice, but Opera
+ * (already) takes more (see Mantis #1633), so we've increased the
+ * value to support something longer...
  */
-#define MAX_NONCE_LENGTH 41
+#define MAX_NONCE_LENGTH 129
 
 
 /**
@@ -228,6 +230,11 @@ struct MHD_Response
    */
   uint64_t data_start;
 
+  /**
+   * Offset to start reading from when using 'fd'.
+   */
+  off_t fd_off;
+
   /**
    * Size of data.
    */
@@ -698,6 +705,7 @@ struct MHD_Connection
    * Memory location to return for protocol session info.
    */
   int cipher;
+
 #endif
 };
 
@@ -824,6 +832,11 @@ struct MHD_Daemon
    */
   size_t pool_size;
 
+  /**
+   * Size of threads created by MHD.
+   */
+  size_t thread_stack_size;
+
   /**
    * Number of worker daemons
    */
@@ -908,6 +921,11 @@ struct MHD_Daemon
    */
   const char *https_mem_cert;
 
+  /**
+   * Pointer to our SSL/TLS certificate authority (in ASCII) in memory.
+   */
+  const char *https_mem_trust;
+
 #endif
 
 #ifdef DAUTH_SUPPORT
